@@ -9,6 +9,7 @@ from .LocalVersionSession import LocalVersionSession
 from .MercurialRepoSession import MercurialRepoSession
 from .SourceForgeRepoSession import SourceForgeRepoSession
 from .FeedRepoSession import FeedRepoSession
+from .PypiRepoSession import PypiRepoSession
 
 log = logging.getLogger(__name__)
 
@@ -18,6 +19,7 @@ class HolderFactory:
         'github': GitHubRepoSession,
         'gitlab': GitLabRepoSession,
         'bitbucket': BitBucketRepoSession,
+        'pip': PypiRepoSession,
         'hg': MercurialRepoSession,
         'sf': SourceForgeRepoSession,
         'website-feed': FeedRepoSession,
