@@ -28,7 +28,7 @@ log = logging.getLogger(__name__)
 
 
 def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
-           short_urls=False, major=None, only=None):
+           short_urls=False, major=None, only=None, at=None):
     cache_dir = user_cache_dir("lastversion")
     log.info("Using cache directory: {}.".format(cache_dir))
     repo_data = {}
@@ -45,7 +45,10 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
                 repo_data['name'] = name
 
     # find the right hosting for this repo
-    project_holder = HolderFactory.get_instance_for_repo(repo, only=only)
+    if not at or '/' in repo:
+        project_holder = HolderFactory.get_instance_for_repo(repo, only=only)
+    else:
+        project_holder = HolderFactory.HOLDERS[at](repo, hostname=None)
 
     # we are completely "offline" for 1 hour, not even making conditional requests
     # heuristic=ExpiresAfter(hours=1)   <- make configurable
@@ -57,6 +60,13 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     if not release:
         return None
 
+    from_type = 'Located the latest release at: {}'.format(
+        project_holder.get_canonical_link()
+    )
+    if 'type' in release:
+        from_type = '{} via {} mechanism'.format(from_type, release['type'])
+    log.info(from_type)
+
     version = release['version']
     tag = release['tag_name']
 
@@ -64,12 +74,18 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     if output_format == 'version':
         return version
 
-    if output_format == 'json':
-        release['version'] = str(version)
-        release['tag_date'] = str(release['tag_date'])
+    if output_format in ['json', 'dict']:
+        if output_format == 'dict':
+            release['version'] = version
+            release['tag_date'] = release['tag_date']
+        else:
+            release['version'] = str(version)
+            release['tag_date'] = str(release['tag_date'])
         release['v_prefix'] = tag.startswith("v")
         version_macro = 'upstream_version' if 'module_of' in repo_data else 'version'
         version_macro = '%{{{}}}'.format(version_macro)
+        holder_i = {value: key for key, value in HolderFactory.HOLDERS.items()}
+        release['source'] = holder_i[type(project_holder)]
         release['spec_tag'] = tag.replace(
             str(version),
             version_macro
@@ -87,7 +103,11 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
         if hasattr(s, 'repo_readme'):
             release['readme'] = s.repo_readme(tag)
         release.update(repo_data)
-        release['assets'] = s.get_assets(release, short_urls, assets_filter)
+        try:
+            release['assets'] = s.get_assets(release, short_urls, assets_filter)
+        except NotImplementedError:
+            pass
+        release['from'] = project_holder.get_canonical_link()
         return release
 
     if output_format == 'assets':
@@ -102,8 +122,8 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     return None
 
 
-def has_update(repo, current_version, pre_ok=False):
-    latest_version = latest(repo, output_format='version', pre_ok=pre_ok)
+def has_update(repo, current_version, pre_ok=False, at=None):
+    latest_version = latest(repo, output_format='version', pre_ok=pre_ok, at=at)
     if latest_version and latest_version > Version(current_version):
         return latest_version
     return False
@@ -137,7 +157,7 @@ def parse_version(tag):
 
 def main():
     epilog = None
-    if "GITHUB_API_TOKEN" not in os.environ:
+    if "GITHUB_API_TOKEN" not in os.environ and "GITHUB_TOKEN" not in os.environ:
         epilog = TOKEN_PRO_TIP
     parser = argparse.ArgumentParser(description='Find the latest release from '
                                                  'GitHub/GitLab/BitBucket.',
@@ -180,13 +200,17 @@ def main():
                                                           "expression")
     parser.add_argument('-su', '--shorter-urls', dest='shorter_urls', action='store_true',
                         help='A tiny bit shorter URLs produced')
+    parser.add_argument('--at', dest='at',
+                        help='If the repo argument is one word, specifies where to look up the '
+                             'project. The default is via internal lookup or GitHub Search',
+                        choices=HolderFactory.HOLDERS.keys())
     parser.add_argument('-y', '--assumeyes', dest='assumeyes', action='store_true',
                         help='Automatically answer yes for all questions')
     parser.add_argument('--version', action='version',
                         version='%(prog)s {version}'.format(version=__version__))
     parser.set_defaults(validate=True, verbose=False, format='version',
                         pre=False, assets=False, newer_than=False, filter=False,
-                        shorter_urls=False, major=None, ssumeyes=False)
+                        shorter_urls=False, major=None, assumeyes=False, at=None)
     args = parser.parse_args()
 
     if args.repo == "self":
@@ -250,10 +274,11 @@ def main():
     # other action are either getting release or doing something with release (extend get action)
     try:
         res = latest(args.repo, args.format, args.pre, args.filter,
-                     args.shorter_urls, args.major, args.only)
+                     args.shorter_urls, args.major, args.only, args.at)
     except (ApiCredentialsError, BadProjectError) as error:
         sys.stderr.write(str(error) + os.linesep)
-        if isinstance(error, ApiCredentialsError) and "GITHUB_API_TOKEN" not in os.environ:
+        if isinstance(error, ApiCredentialsError) and "GITHUB_API_TOKEN" not in os.environ and \
+                "GITHUB_TOKEN" not in os.environ:
             sys.stderr.write(TOKEN_PRO_TIP + os.linesep)
         sys.exit(4)
 
